// vim:ts=4:sw=4
// lang.cc : runtime language support added by Shard <shard@>
//
// Copyright (c) under GPL 1998-2003 Sean Dwyer <ewe2@can.org.au>

static char rcsid[] __attribute__ ((unused)) = "@(#) $Id: lang.cc,v 1.3 2003/09/22 00:12:29 ewe2 Exp $";

#include "lang.hh"

// include your header file here.
#define STATIC_HELP
#include "en.h"
#include "es.h"
#include "pl.h"
#include "de.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace std;

// these are defaults (ie default language is C/en)

// FIXME but we should give users the option to stick with one default
// language, and possibly bypass other languages.

#ifdef DEF_EN
const char* helptext = en_helptext;
const char* MSG_CERR = EN_MSG_CERR;
const char* MSG_DERR = EN_MSG_DERR;
const char* MSG_JERR = EN_MSG_JERR;
const char* MSG_LERR = EN_MSG_LERR;
const char* MSG_OPTERR = EN_MSG_OPTERR;
const char* MSG_NONOPTERR = EN_MSG_NONOPTERR;
const char* MSG_LONGERR = EN_MSG_LONGERR;
const char* MSG_GENERR = EN_MSG_GENERR;
const char* MSG_ILC = EN_MSG_ILC;
const char* MSG_IGD = EN_MSG_IGD;
const char* MSG_IJDN = EN_MSG_IJDN;
const char* MSG_FORMATERR = EN_MSG_FORMATERR;
const char* pretty_format = en_pretty_format;
const char* default_format = en_default_format;
#endif

#ifdef DEF_DE
const char* helptext = de_helptext;
const char* MSG_CERR = DE_MSG_CERR;
const char* MSG_DERR = DE_MSG_DERR;
const char* MSG_JERR = DE_MSG_JERR;
const char* MSG_LERR = DE_MSG_LERR;
const char* MSG_OPTERR = DE_MSG_OPTERR;
const char* MSG_NONOPTERR = DE_MSG_NONOPTERR;
const char* MSG_LONGERR = DE_MSG_LONGERR;
const char* MSG_GENERR = DE_MSG_GENERR;
const char* MSG_ILC = DE_MSG_ILC;
const char* MSG_IGD = DE_MSG_IGD;
const char* MSG_IJDN = DE_MSG_IJDN;
const char* MSG_FORMATERR = DE_MSG_FORMATERR;
const char* pretty_format = de_pretty_format;
const char* default_format = de_default_format;
#endif

#ifdef DEF_ES
const char* helptext = es_helptext;
const char* MSG_CERR = ES_MSG_CERR;
const char* MSG_DERR = ES_MSG_DERR;
const char* MSG_JERR = ES_MSG_JERR;
const char* MSG_LERR = ES_MSG_LERR;
const char* MSG_OPTERR = ES_MSG_OPTERR;
const char* MSG_NONOPTERR = ES_MSG_NONOPTERR;
const char* MSG_LONGERR = ES_MSG_LONGERR;
const char* MSG_GENERR = ES_MSG_GENERR;
const char* MSG_ILC = ES_MSG_ILC;
const char* MSG_IGD = ES_MSG_IGD;
const char* MSG_IJDN = ES_MSG_IJDN;
const char* MSG_FORMATERR = ES_MSG_FORMATERR;
const char* pretty_format = es_pretty_format;
const char* default_format = es_default_format;
#endif

#ifdef DEF_PL
const char* helptext = pl_helptext;
const char* MSG_CERR = PL_MSG_CERR;
const char* MSG_DERR = PL_MSG_DERR;
const char* MSG_JERR = PL_MSG_JERR;
const char* MSG_LERR = PL_MSG_LERR;
const char* MSG_OPTERR = PL_MSG_OPTERR;
const char* MSG_NONOPTERR = PL_MSG_NONOPTERR;
const char* MSG_LONGERR = PL_MSG_LONGERR;
const char* MSG_GENERR = PL_MSG_GENERR;
const char* MSG_ILC = PL_MSG_ILC;
const char* MSG_IGD = PL_MSG_IGD;
const char* MSG_IJDN = PL_MSG_IJDN;
const char* MSG_FORMATERR = PL_MSG_FORMATERR;
const char* pretty_format = pl_pretty_format;
const char* default_format = pl_default_format;
#endif


// a simple idea. for each character of the include, if it matches, we set the
// defaults. this is the entire runtime support, which could be bypassed.
int set_lang(const char *lang)
{
	const char *c = lang;
	switch(*c)
	{
		case 'e':			// currently covers en, es
		{
			c++;
			if (*c == 'n') {
				helptext = en_helptext;
				MSG_CERR = EN_MSG_CERR;
				MSG_DERR = EN_MSG_DERR;
				MSG_JERR = EN_MSG_JERR;
				MSG_LERR = EN_MSG_LERR;
				MSG_OPTERR = EN_MSG_OPTERR;
				MSG_NONOPTERR = EN_MSG_NONOPTERR;
				MSG_LONGERR = EN_MSG_LONGERR;
				MSG_GENERR = EN_MSG_GENERR;
				MSG_ILC = EN_MSG_ILC;
				MSG_IGD = EN_MSG_IGD;
				MSG_IJDN = EN_MSG_IJDN;
				MSG_FORMATERR = EN_MSG_FORMATERR;

				pretty_format = en_pretty_format;
				default_format = en_default_format;
			}
			else if (*c == 's') {
				helptext = es_helptext;
				MSG_CERR = ES_MSG_CERR;
				MSG_DERR = ES_MSG_DERR;
				MSG_JERR = ES_MSG_JERR;
				MSG_LERR = ES_MSG_LERR;
				MSG_OPTERR = ES_MSG_OPTERR;
				MSG_NONOPTERR = ES_MSG_NONOPTERR;
				MSG_LONGERR = ES_MSG_LONGERR;
				MSG_GENERR = ES_MSG_GENERR;
				MSG_ILC = ES_MSG_ILC;
				MSG_IGD = ES_MSG_IGD;
				MSG_IJDN = ES_MSG_IJDN;
				MSG_FORMATERR = ES_MSG_FORMATERR;

				pretty_format = es_pretty_format;
				default_format = es_default_format;
			}
			break;
		}

		case 'd':		// german
		{
			c++;
			if (*c == 'e')
			{
				helptext = de_helptext;

                MSG_CERR = DE_MSG_CERR;
                MSG_DERR = DE_MSG_DERR;
                MSG_JERR = DE_MSG_JERR;
                MSG_LERR = DE_MSG_LERR;
                MSG_OPTERR = DE_MSG_OPTERR;
				MSG_NONOPTERR = DE_MSG_NONOPTERR;
				MSG_LONGERR = DE_MSG_LONGERR;
				MSG_GENERR = DE_MSG_GENERR;
				MSG_ILC = DE_MSG_ILC;
				MSG_IGD = DE_MSG_IGD;
				MSG_IJDN = DE_MSG_IJDN;
				MSG_FORMATERR = DE_MSG_FORMATERR;

				pretty_format = de_pretty_format;
				default_format = de_default_format;
			}
			break;
		}
		
		case 'p':		// polish
		{
			c++;
			if (*c == 'l') {
				helptext = pl_helptext;

				MSG_CERR = PL_MSG_CERR;
				MSG_DERR = PL_MSG_DERR;
				MSG_JERR = PL_MSG_JERR;
				MSG_LERR = PL_MSG_LERR;
				MSG_OPTERR = PL_MSG_OPTERR;
				MSG_NONOPTERR = PL_MSG_NONOPTERR;
				MSG_LONGERR = PL_MSG_LONGERR;
				MSG_GENERR = PL_MSG_GENERR;
				MSG_ILC = PL_MSG_ILC;
				MSG_IGD = PL_MSG_IGD;
				MSG_IJDN = PL_MSG_IJDN;
				MSG_FORMATERR = PL_MSG_FORMATERR;

				pretty_format = pl_pretty_format;
				default_format = pl_default_format;
			}
			break;
		}

		default:
			break;
	}
	return 0;
}
